pub struct DeviceWatchControllerWriteCommandsRequest {
pub address: u8,
pub size: u16,
pub setup_wake_lease: Option<EventPair>,
}Fields
address: u8size: u16setup_wake_lease: Option<EventPair>Trait Implementations
Sourceimpl<___E> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceWatchControllerWriteCommandsRequest>, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
DeviceWatchControllerWriteCommandsRequest: Encode<DeviceWatchControllerWriteCommandsRequest, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceWatchControllerWriteCommandsRequest>, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
DeviceWatchControllerWriteCommandsRequest: Encode<DeviceWatchControllerWriteCommandsRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceWatchControllerWriteCommandsRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceWatchControllerWriteCommandsRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceWatchControllerWriteCommandsRequest> for DeviceWatchControllerWriteCommandsRequest
impl FromWire<DeviceWatchControllerWriteCommandsRequest> for DeviceWatchControllerWriteCommandsRequest
Sourcefn from_wire(wire: DeviceWatchControllerWriteCommandsRequest) -> Self
fn from_wire(wire: DeviceWatchControllerWriteCommandsRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for DeviceWatchControllerWriteCommandsRequest
impl PartialEq for DeviceWatchControllerWriteCommandsRequest
Sourcefn eq(&self, other: &DeviceWatchControllerWriteCommandsRequest) -> bool
fn eq(&self, other: &DeviceWatchControllerWriteCommandsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceWatchControllerWriteCommandsRequest