pub struct DeviceWatchControllerWriteCommandsResponse {
pub writes: Vec<Register8>,
pub wake_lease: Option<EventPair>,
}Fields
writes: Vec<Register8>wake_lease: Option<EventPair>Trait Implementations
Sourceimpl<___E> Encode<DeviceWatchControllerWriteCommandsResponse<'static>, ___E> for DeviceWatchControllerWriteCommandsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<DeviceWatchControllerWriteCommandsResponse<'static>, ___E> for DeviceWatchControllerWriteCommandsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceWatchControllerWriteCommandsResponse<'static>>, ___E> for DeviceWatchControllerWriteCommandsResponsewhere
___E: Encoder + ?Sized,
DeviceWatchControllerWriteCommandsResponse: Encode<DeviceWatchControllerWriteCommandsResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceWatchControllerWriteCommandsResponse<'static>>, ___E> for DeviceWatchControllerWriteCommandsResponsewhere
___E: Encoder + ?Sized,
DeviceWatchControllerWriteCommandsResponse: Encode<DeviceWatchControllerWriteCommandsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceWatchControllerWriteCommandsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceWatchControllerWriteCommandsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceWatchControllerWriteCommandsResponse<'de>> for DeviceWatchControllerWriteCommandsResponse
impl<'de> FromWire<DeviceWatchControllerWriteCommandsResponse<'de>> for DeviceWatchControllerWriteCommandsResponse
Sourcefn from_wire(wire: DeviceWatchControllerWriteCommandsResponse<'de>) -> Self
fn from_wire(wire: DeviceWatchControllerWriteCommandsResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for DeviceWatchControllerWriteCommandsResponse
impl PartialEq for DeviceWatchControllerWriteCommandsResponse
Sourcefn eq(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> bool
fn eq(&self, other: &DeviceWatchControllerWriteCommandsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceWatchControllerWriteCommandsResponse