pub struct DeviceCancelWatchControllerWriteCommandsRequest {
pub address: u8,
pub size: u16,
}Fields
address: u8size: u16Trait Implementations
Sourceimpl Clone for DeviceCancelWatchControllerWriteCommandsRequest
impl Clone for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn clone(&self) -> DeviceCancelWatchControllerWriteCommandsRequest
fn clone(&self) -> DeviceCancelWatchControllerWriteCommandsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
&'a DeviceCancelWatchControllerWriteCommandsRequest: Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
&'a DeviceCancelWatchControllerWriteCommandsRequest: Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceCancelWatchControllerWriteCommandsRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceCancelWatchControllerWriteCommandsRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
DeviceCancelWatchControllerWriteCommandsRequest: Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: Encoder + ?Sized,
DeviceCancelWatchControllerWriteCommandsRequest: Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E>,
Sourcefn encode_option(
this: Option<DeviceCancelWatchControllerWriteCommandsRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceCancelWatchControllerWriteCommandsRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceCancelWatchControllerWriteCommandsRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
impl FromWire<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn from_wire(
wire: DeviceCancelWatchControllerWriteCommandsRequest,
) -> DeviceCancelWatchControllerWriteCommandsRequest
fn from_wire( wire: DeviceCancelWatchControllerWriteCommandsRequest, ) -> DeviceCancelWatchControllerWriteCommandsRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
impl FromWireRef<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn from_wire_ref(
wire: &DeviceCancelWatchControllerWriteCommandsRequest,
) -> DeviceCancelWatchControllerWriteCommandsRequest
fn from_wire_ref( wire: &DeviceCancelWatchControllerWriteCommandsRequest, ) -> DeviceCancelWatchControllerWriteCommandsRequest
Converts the given reference to this type.
Sourceimpl Ord for DeviceCancelWatchControllerWriteCommandsRequest
impl Ord for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn cmp(
&self,
other: &DeviceCancelWatchControllerWriteCommandsRequest,
) -> Ordering
fn cmp( &self, other: &DeviceCancelWatchControllerWriteCommandsRequest, ) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceCancelWatchControllerWriteCommandsRequest
impl PartialEq for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn eq(&self, other: &DeviceCancelWatchControllerWriteCommandsRequest) -> bool
fn eq(&self, other: &DeviceCancelWatchControllerWriteCommandsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceCancelWatchControllerWriteCommandsRequest
impl PartialOrd for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn partial_cmp(
&self,
other: &DeviceCancelWatchControllerWriteCommandsRequest,
) -> Option<Ordering>
fn partial_cmp( &self, other: &DeviceCancelWatchControllerWriteCommandsRequest, ) -> Option<Ordering>
impl Copy for DeviceCancelWatchControllerWriteCommandsRequest
impl Eq for DeviceCancelWatchControllerWriteCommandsRequest
impl StructuralPartialEq for DeviceCancelWatchControllerWriteCommandsRequest