pub struct SubTargetService;Expand description
The type corresponding to the SubTargetService service. This service represents a sub-target device within an SPMI target. Clients have access to a subset of the SPMI register range as determined by the controller driver.