#[repr(C)]pub struct DebugConnectTargetRequest {
pub target_id: u8,
pub server: ServerEnd<Device, Channel>,
}Expand description
The wire type corresponding to DebugConnectTargetRequest.
Fields
target_id: u8server: ServerEnd<Device, Channel>Trait Implementations
Sourceimpl Constrained for DebugConnectTargetRequest
impl Constrained for DebugConnectTargetRequest
Sourceimpl Debug for DebugConnectTargetRequest
impl Debug for DebugConnectTargetRequest
Sourceimpl<___D> Decode<___D> for DebugConnectTargetRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DebugConnectTargetRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DebugConnectTargetRequest, ___E> for DebugConnectTargetRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DebugConnectTargetRequest, ___E> for DebugConnectTargetRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugConnectTargetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugConnectTargetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<DebugConnectTargetRequest, ___E> for DebugConnectTargetRequest<T0, T1>
impl<___E, T0, T1> Encode<DebugConnectTargetRequest, ___E> for DebugConnectTargetRequest<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugConnectTargetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugConnectTargetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DebugConnectTargetRequest> for DebugConnectTargetRequest
impl FromWire<DebugConnectTargetRequest> for DebugConnectTargetRequest
Sourcefn from_wire(wire: DebugConnectTargetRequest) -> Self
fn from_wire(wire: DebugConnectTargetRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl IntoNatural for DebugConnectTargetRequest
impl IntoNatural for DebugConnectTargetRequest
Sourcetype Natural = DebugConnectTargetRequest
type Natural = DebugConnectTargetRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DebugConnectTargetRequest
impl Wire for DebugConnectTargetRequest
Sourcetype Narrowed<'de> = DebugConnectTargetRequest
type Narrowed<'de> = DebugConnectTargetRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.