#[repr(C)]pub struct DeviceCancelWatchControllerWriteCommandsRequest {
pub address: u8,
pub size: Uint16,
}Expand description
The wire type corresponding to DeviceCancelWatchControllerWriteCommandsRequest.
Fields
address: u8size: Uint16Trait Implementations
Sourceimpl Clone for DeviceCancelWatchControllerWriteCommandsRequest
impl Clone for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn clone(&self) -> DeviceCancelWatchControllerWriteCommandsRequest
fn clone(&self) -> DeviceCancelWatchControllerWriteCommandsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceCancelWatchControllerWriteCommandsRequest
impl Constrained for DeviceCancelWatchControllerWriteCommandsRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceCancelWatchControllerWriteCommandsRequest>,
_: <DeviceCancelWatchControllerWriteCommandsRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceCancelWatchControllerWriteCommandsRequest>, _: <DeviceCancelWatchControllerWriteCommandsRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for &'a DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequest<T0, T1>
impl<___E, T0, T1> Encode<DeviceCancelWatchControllerWriteCommandsRequest, ___E> for DeviceCancelWatchControllerWriteCommandsRequest<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
impl FromWire<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn from_wire(
wire: DeviceCancelWatchControllerWriteCommandsRequest,
) -> DeviceCancelWatchControllerWriteCommandsRequest
fn from_wire( wire: DeviceCancelWatchControllerWriteCommandsRequest, ) -> DeviceCancelWatchControllerWriteCommandsRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
impl FromWireRef<DeviceCancelWatchControllerWriteCommandsRequest> for DeviceCancelWatchControllerWriteCommandsRequest
Sourcefn from_wire_ref(
wire: &DeviceCancelWatchControllerWriteCommandsRequest,
) -> DeviceCancelWatchControllerWriteCommandsRequest
fn from_wire_ref( wire: &DeviceCancelWatchControllerWriteCommandsRequest, ) -> DeviceCancelWatchControllerWriteCommandsRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceCancelWatchControllerWriteCommandsRequest
impl IntoNatural for DeviceCancelWatchControllerWriteCommandsRequest
Sourcetype Natural = DeviceCancelWatchControllerWriteCommandsRequest
type Natural = DeviceCancelWatchControllerWriteCommandsRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceCancelWatchControllerWriteCommandsRequest
impl Wire for DeviceCancelWatchControllerWriteCommandsRequest
Sourcetype Narrowed<'de> = DeviceCancelWatchControllerWriteCommandsRequest
type Narrowed<'de> = DeviceCancelWatchControllerWriteCommandsRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(
out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>,
)
fn zero_padding( out_: &mut MaybeUninit<DeviceCancelWatchControllerWriteCommandsRequest>, )
Writes zeroes to the padding for this type, if any.