#[repr(C)]pub struct DeviceRegisterReadRequest {
pub address: Uint16,
pub size_bytes: Uint32,
}Expand description
The wire type corresponding to DeviceRegisterReadRequest.
Fields
address: Uint16size_bytes: Uint32Trait Implementations
Sourceimpl Clone for DeviceRegisterReadRequest
impl Clone for DeviceRegisterReadRequest
Sourcefn clone(&self) -> DeviceRegisterReadRequest
fn clone(&self) -> DeviceRegisterReadRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceRegisterReadRequest
impl Constrained for DeviceRegisterReadRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceRegisterReadRequest>,
_: <DeviceRegisterReadRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceRegisterReadRequest>, _: <DeviceRegisterReadRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceRegisterReadRequest
impl Debug for DeviceRegisterReadRequest
Sourceimpl<___D> Decode<___D> for DeviceRegisterReadRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceRegisterReadRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceRegisterReadRequest, ___E> for &'a DeviceRegisterReadRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRegisterReadRequest, ___E> for &'a DeviceRegisterReadRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterReadRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterReadRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRegisterReadRequest, ___E> for DeviceRegisterReadRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRegisterReadRequest, ___E> for DeviceRegisterReadRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterReadRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterReadRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<DeviceRegisterReadRequest, ___E> for DeviceRegisterReadRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<DeviceRegisterReadRequest, ___E> for DeviceRegisterReadRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterReadRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterReadRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceRegisterReadRequest> for DeviceRegisterReadRequest
impl FromWire<DeviceRegisterReadRequest> for DeviceRegisterReadRequest
Sourcefn from_wire(wire: DeviceRegisterReadRequest) -> DeviceRegisterReadRequest
fn from_wire(wire: DeviceRegisterReadRequest) -> DeviceRegisterReadRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<DeviceRegisterReadRequest> for DeviceRegisterReadRequest
impl FromWireRef<DeviceRegisterReadRequest> for DeviceRegisterReadRequest
Sourcefn from_wire_ref(wire: &DeviceRegisterReadRequest) -> DeviceRegisterReadRequest
fn from_wire_ref(wire: &DeviceRegisterReadRequest) -> DeviceRegisterReadRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceRegisterReadRequest
impl IntoNatural for DeviceRegisterReadRequest
Sourcetype Natural = DeviceRegisterReadRequest
type Natural = DeviceRegisterReadRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceRegisterReadRequest
impl Wire for DeviceRegisterReadRequest
Sourcetype Narrowed<'de> = DeviceRegisterReadRequest
type Narrowed<'de> = DeviceRegisterReadRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceRegisterReadRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceRegisterReadRequest>)
Writes zeroes to the padding for this type, if any.