#[repr(C)]pub struct DeviceWatchControllerWriteCommandsRequest {
pub address: u8,
pub size: Uint16,
pub setup_wake_lease: OptionalEventPair,
}Expand description
The wire type corresponding to DeviceWatchControllerWriteCommandsRequest.
Fields
address: u8size: Uint16setup_wake_lease: OptionalEventPairTrait Implementations
Sourceimpl Constrained for DeviceWatchControllerWriteCommandsRequest
impl Constrained for DeviceWatchControllerWriteCommandsRequest
Sourceimpl<___D> Decode<___D> for DeviceWatchControllerWriteCommandsRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceWatchControllerWriteCommandsRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequest<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<DeviceWatchControllerWriteCommandsRequest, ___E> for DeviceWatchControllerWriteCommandsRequest<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceWatchControllerWriteCommandsRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceWatchControllerWriteCommandsRequest> for DeviceWatchControllerWriteCommandsRequest
impl FromWire<DeviceWatchControllerWriteCommandsRequest> for DeviceWatchControllerWriteCommandsRequest
Sourcefn from_wire(wire: DeviceWatchControllerWriteCommandsRequest) -> Self
fn from_wire(wire: DeviceWatchControllerWriteCommandsRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl IntoNatural for DeviceWatchControllerWriteCommandsRequest
impl IntoNatural for DeviceWatchControllerWriteCommandsRequest
Sourcetype Natural = DeviceWatchControllerWriteCommandsRequest
type Natural = DeviceWatchControllerWriteCommandsRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceWatchControllerWriteCommandsRequest
impl Wire for DeviceWatchControllerWriteCommandsRequest
Sourcetype Narrowed<'de> = DeviceWatchControllerWriteCommandsRequest
type Narrowed<'de> = DeviceWatchControllerWriteCommandsRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.