DebugLocalServerHandler

Trait DebugLocalServerHandler 

pub trait DebugLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn connect_target(
        &mut self,
        request: Request<ConnectTarget, ___T>,
        responder: Responder<ConnectTarget, ___T>,
    ) -> impl Future<Output = ()>;
    fn get_controller_properties(
        &mut self,
        responder: Responder<GetControllerProperties, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the Debug protocol.

See [Debug] for more details.

Required Methods

fn connect_target( &mut self, request: Request<ConnectTarget, ___T>, responder: Responder<ConnectTarget, ___T>, ) -> impl Future<Output = ()>

Connects to the target device with the given ID. Equivalent to connecting to TargetService via the corresponding driver node.

Returns INVALID_ARGS if target_id is greater than or equal to MAX_TARGETS. May return an error if there is no such target on the bus; otherwise errors will be returned when attempting to access the client.

fn get_controller_properties( &mut self, responder: Responder<GetControllerProperties, ___T>, ) -> impl Future<Output = ()>

Returns the properties of the host SPMI controller.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> DebugLocalServerHandler<___T> for Local<___H>
where ___H: DebugServerHandler<___T>, ___T: Transport,

Source

async fn connect_target( &mut self, request: Request<ConnectTarget, ___T>, responder: Responder<ConnectTarget, ___T>, )

Source

async fn get_controller_properties( &mut self, responder: Responder<GetControllerProperties, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors